package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!0````!$``94````#0``+Z4```````T`"``
M"``H`!\`'@````8````T$```-!```#0```$````!``````4````$`````P``
M`300``$T$``!-`````T````-````!`````$````!`````!`````0``````"Z
MO```NKP````%``$```````$``+J\$`&ZO!`!NKP```*(```2U`````8``0``
M`````@``NMP0`;K<$`&ZW````0````$`````!@````0````$```!1!```400
M``%$````1````$0````$````!&1TY5```+I\$`"Z?!``NGP````4````%```
M``0````$9'3E40``````````````````````````````!@````0O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````"````!@```!(````$
M````%`````-'3E4`AN4_@H*O]+AV\5\$X`L;U*QZ`<L```!A````=0````H`
M`````````````$,`````````1P```$8`````````2@```%P````^````.0``
M`$L````#````6``````````P````80```%0````R````;0```&D````$````
M*P``````````````*0```&4````=``````````````!F````2````&<````(
M````<0```%$```!T````3````$X`````````'@````````!R`````````%``
M``!N``````````````!H````)P`````````Z``````````````!;````-0``
M`$````!%```````````````2`````````#\``````````````"(`````````
M&P```"\````+````,0```"@```!3``````````````!=````;````#P```!@
M````30```#L````T``````````P```````````````````!5````9```````
M``!$````7P```$(````]````)@````$`````````````````````````````
M``````````````````````````````````````!/````````````````````
M```````````.``````````\````4````8@```````````````````!,`````
M`````````!$`````````&`````````````````````````!6`````````%<`
M````````:@``````````````$````````````````````!H`````````)0``
M`&L````%````(P````<`````````+@```"0````-````'`````````!C````
M(``````````9````"0``````````````00`````````S````+0```&\```!S
M````7@```````````````````$D````&````````````````````````````
M`````````````%H````A`````````!8`````````<````!<`````````-@``
M```````J`````````````````````````%D`````````%0````````!2````
M`````````````````````#<``````````@`````````?````+````#@````E
M````3P````@````(!!`0`(($0"4!``"HJ`&&H@(@!$`I!"A/1S*B.`@,A(H`
M``!/````4````````````````````%(```!4````50```%8```!7````6```
M`%D```!:````7````%T`````````7@```````````````````%\```!B````
M``````````!C````90```&8```!H`````````&H```!L``````````````!N
M````;P```'(`````<;+5R2U'WLY)^^"C#N_3ZFNCW:>VF\4OGN/-VWM?[^>!
MG/F'UD,):QR+\CD+ESH,Q@681Y`%B<6>XA0-#N3_(6^+`;)`G+G$?)I_:YN<
MJ7\?W\5N'%AQV7R2X[M\U&34P.-+K>W;8C(*`J?A9LRO9FM*\'L!QD?B[-5%
M0\6.07VI8<J4+#_EPB`+(J$=T]OR8&RA^@[QC;D`````````````````````
M```"X@``````````$@```````+$``````````!(```````.=```````````2
M```````#B```````````$@```````:$``````````!(```````)Z````````
M```2````````$0``````````(````````"```````````"````````..````
M```````2```````!C0``````````$@```````^```````````!(```````%N
M```````````2```````!@```````````$@```````V@``````````!(`````
M``,O```````````2```````##@``````````$@```````BP``````````!(`
M``````#]```````````2```````"'```````````$@```````[(`````````
M`!(```````'*```````````2```````$/@``````````$@```````O,`````
M`````!(```````+7```````````2```````"F```````````$@```````>H`
M`````````!(```````&F```````````2```````"-0``````````$@``````
M`\T``````````!(```````0P```````````2```````!+P``````````$@``
M`````]@``````````!(````````T```````````2```````#Z@``````````
M$@```````5T``````````!(```````#(```````````2```````$'@``````
M````$@```````\8``````````!(```````0/```````````2```````#JP``
M````````$@```````X$``````````!(```````41```````````2```````!
M00``````````$@```````_\``````````!(```````)<```````````2````
M```#7P``````````$@```````MP``````````!(```````).```````````2
M```````#N0``````````$@``````!!8``````````!(```````*1````````
M```2```````!JP``````````$@```````W```````````!(```````/`````
M```````2```````#I```````````$@```````.P``````````!(```````!"
M```````````2```````$!@``````````$@``````!"@``````````!(`````
M``#7```````````2```````!_@``````````$@```````H4``````````!(`
M``````%0```````````2```````#E@``````````$@```````TX`````````
M`!(```````,'```````````2```````!'0``````````$@```````D,`````
M`````!(```````!4```````````2```````!V```````````$@```````&,`
M`````````!(```````0W```````````2````````CP``````````$@``````
M`U8``````````!(```````-!```````````2```````#1@``````````$@``
M`````'@``````````!(```````$+```````````2```````!MQ``5```````
M$@``````!8\0`$&P```*_!(```T```6[$``W`````D02```-```$J!``6B``
M````$@``#@``!%(0`;U4````!"$``!L```2`$``RT`````P2```-```%.Q``
M4F````"T$@``#0``!5`0`%Z(``!;ZA$```\```"@$`!5T``````2```````%
M)A`!O2P`````$```&0```_@0`;U0````!!$``!L```4H$`&]+``````@```9
M```%2Q`!O3P````$$0``&@``!%$0`;U4````!"$``!L```2>$`!24`````02
M```-```%KA``/R````*($@``#0``!,00`"K0````G!(```T```10$`&]5```
M``01```;```$2Q``/&````*T$@``#0``!/\0`#E0````.!(```T```4:$``[
M@````-@2```-```$;Q`!O40`````$`#_\0``!'L0`<V0`````!``__$```2N
M$`!,L```!(P2```-```#(!``6F@````$$0``#P``!2P0`!E0````)!(```T`
M``32$``Q\````-@2```-```$\Q``.9````'P$@``#0```FH0`%7``````!(`
M``````21$``:P````&@2```-```$:!`!O40`````$`#_\0``!5\0`"T@````
M5!(```T```3H$`(]/``````0```:```%,Q``44````!($@``#0``!7L0`;U`
M````!!$``!H```*C$`&]8````!,1```;```%G!``-7````&0$@``#0``!340
M`!C\`````!(```P`;&EB<&5R;"YS;RXU+C$P`%]?9VUO;E]S=&%R=%]?`%]*
M=E]296=I<W1E<D-L87-S97,`4&5R;%]S>7-?=&5R;0!097)L7TES=&%T8G5F
M7W!T<@!097)L7W-Y<U]I;FET,P!097)L7TEE>&ET7V9L86=S7W!T<@!097)L
M7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?26-O;7!C=E]P='(`4&5R;%]A=&9O
M<FM?;&]C:P!097)L7TEC=7)S=&%C:VEN9F]?<'1R`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?27!A<G-E<E]P='(`4&5R;%]A
M=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7TET;W!?96YV7W!T<@!0
M97)L7TET86EN=&5D7W!T<@!097)L7W-V7W-E='!V;@!097)L7VYE=U-6<'8`
M4&5R;%]N97=84U]F;&%G<P!097)L7TEI;E]E=F%L7W!T<@!097)L7TEO<%]P
M='(`4&5R;%])979A;%]R;V]T7W!T<@!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]'=&AR7VME
M>5]P='(`4&5R;%]'9&]?=6YD=6UP7W!T<@!097)L7TEP97)L7V1E<W1R=6-T
M7VQE=F5L7W!T<@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D;W5N
M=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N
M-@!L:6)P=&AR96%D+G-O+C``<F5A9`!C;&]S90!?7V5R<FYO7VQO8V%T:6]N
M`'!T:')E861?9V5T<W!E8VEF:6,`;W!E;C8T`&QS965K-C0`;&EB8RYS;RXV
M`%])3U]S=&1I;E]U<V5D`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W!R:6YT
M9@!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'-T<FYC<'D`7U]S=&%C:U]C
M:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T
M<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`7U]L>'-T
M870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C`'-T9&5R<@!G
M971U:60`<F5A9&QI;FL`97AE8W9P`&9P<FEN=&8`<F5A9&1I<C8T`&UE;6UO
M=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`
M;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`%]31$%?0D%315\`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]D871A7W-T87)T`'AS7VEN:70`
M7U]L:6)C7V-S=5]I;FET`&YA;65?;&]A9%]M>5]P87)?<&P`6%-?26YT97)N
M86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P87)?<&P`<&%R7VUK
M=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R
M+C(`1TQ)0D-?,BXP``````(````#``,````````````#````!````````P`%
M``8``````````P````,``@`"```````#````!``#`````P````<```````0`
M`P`#``,``P`#`````P````,``@````,`"``#````"``#``,```````,``P``
M``````````,``P`&```````````````#`````P`#``@``````````0`!``$`
M`P`!``$``0````$``P`!``$``P`!``$``0`#``$``0`!``$``0`!``$``0`!
M``$````!``$``0`!``$``0````$``0````$`!0```Q8````0````8`UI:10`
M```(```%R````!`-:6D3````!P``!=(````0"6D9<@````4```7<````$`UI
M:1(````$```%Z````!`-:6D0`````P``!?(```````$``@```L<````0````
M``UI:1(````&```%Z````!`-:6D0`````@``!?(`````$`&[W```!Q0`````
M$`&]4```61,`````$`&]5```8!,`````$`&]8```<A,`````$`&[[````14`
M````$`&[\````A4`````$`&[]````Q4`````$`&[^```!!4`````$`&[_```
M!14`````$`&\````!A4`````$`&\!```3Q4`````$`&\"```!Q4`````$`&\
M#```"14`````$`&\$```"A4`````$`&\%```"Q4`````$`&\&```#!4`````
M$`&\'```#14`````$`&\(```#A4`````$`&\)```#Q4`````$`&\*```$!4`
M````$`&\+```$14`````$`&\,```$A4`````$`&\-```$Q4`````$`&\.```
M%!4`````$`&\/```%14`````$`&\0```%A4`````$`&\1```%Q4`````$`&\
M2```&!4`````$`&\3```&14`````$`&\4```&A4`````$`&\5```&Q4`````
M$`&\6```'!4`````$`&\7```'14`````$`&\8```'A4`````$`&\9```'Q4`
M````$`&\:```(!4`````$`&\;```(14`````$`&\<```(A4`````$`&\=```
M:Q4`````$`&\>```5Q4`````$`&\?```(Q4`````$`&\@```)!4`````$`&\
MA```)14`````$`&\B```)A4`````$`&\C```)Q4`````$`&\D```*!4`````
M$`&\E```*14`````$`&\F```*A4`````$`&\G```*Q4`````$`&\H```+!4`
M````$`&\I```+14`````$`&\J```+A4`````$`&\K```+Q4`````$`&\L```
M,!4`````$`&\M```,14`````$`&\N```,A4`````$`&\O```,Q4`````$`&\
MP```-!4`````$`&\Q```-14`````$`&\R```-A4`````$`&\S```-Q4`````
M$`&\T```.!4`````$`&\U```.14`````$`&\V```.A4`````$`&\W```.Q4`
M````$`&\X```/!4`````$`&\Y```/14`````$`&\Z```/A4`````$`&\[```
M/Q4`````$`&\\```0!4`````$`&\]```014`````$`&\^```0A4`````$`&\
M_```0Q4`````$`&]````1!4`````$`&]!```114`````$`&]"```1A4`````
M$`&]#```1Q4`````$`&]$```2!4`````$`&]%```214`````$`&]&```2A4`
M````$`&]'```2Q4`````$`&](```3!4`````$`&])```314`````$`&]*```
M3A4`````E"'_\'P(`J:0`0`4D\$`"$*?``5_R`*F/]X``CO>HM"`'O_\+X``
M`$&>``A(`#KI2``!)4@`.?&``0`4?`@#IH/!``@X(0`03H``(```````````
M?"D+>%0A`#8X````E"'_\'P(`Z:0`0``/0`0`(6H6EA(`#N`````````````
M````E"'_X'P(`J:3@0`0DZ$`%#^`$`*0`0`DD\$`&)/A`!R('+UT+X```$">
M`&0_X!`"/Z`0`C_`$`([O;K$.]ZZR'_=\%"!/[UX?]X6<#O>__]_B?!`0)P`
M,#O_O7A@````.2D``54@$#J1/P``?!T`+GP)`Z9.@`0A@3\``'^)\$!!G/_@
M.````9@<O72``0`D@X$`$(.A`!2#P0`8?`@#IH/A`!PX(0`@3H``(&````"4
M(?_P?`@"II`!`!2``0`4."$`$'P(`Z9.@``@8````#T@$`*4(?_P?`@"ICAI
MNLR0`0`4@`FZS"^```!!G@`</2```#@)```O@```09X`#'P)`Z9.@`0A@`$`
M%#@A`!!\"`.F3H``(&````!@````E"'_\'P(`J:0`0`4@`$`%#@A`!!\"`.F
M3H``(`````"4(?_P?&H;>(@#```O@```09X`3#U@$``Y(P`!@6M:;(EK``!(
M```<8````&````"("0``.2D``2^```!!G@`@?X!8`$">_^R("0``?2I+>#DI
M``$O@```0)[_Z'U#4W@X(0`03H``(&````!@````E"'^H#@``!!\"0.F.4,`
M'#D@``"3@0%0DZ$!5)/!`5B3X0%<.6$`$&````!@````?`I(+GP+22XY*0`$
M0@#_]#DA`$0Y`0%$8````&````"!:?_L@`D``(%)_]1]8`)X@6G_S'P`4GA\
M`%IX5``(/I`)``PY*0`$?XE``$">_]2`@P`0@\$`$(`#``"`PP`$@.,`"("C
M``Q_Q/(4@0$`%(&!`!@_WEJ"5,KP/E0?*#Y\JS!X@X$`''T%0A1\Z3`X.]YY
MF7UI2WA_WOH4?4L`.'S_`'@]"%J"?3Y*%'_K6W@Y"'F9?8=B%'T(6A15*R@^
M?6A:%#V,6H)4"/`^53[P/GU?2'A5?2@^?2E`.#F,>9E]C.H4?^E+>#^<6H)]
M+$H4@8$`('T=6'A]?_`X.YQYF7^_^WA]7%(4/8Q:@H.!`"1_ZOH452HH/GU?
M4A0YC'F957_P/E5=*#Y_RTAX?8Q"%%4H\#Y]*?@X?8SJ%'UI2W@_G%J"?2Q*
M%(&!`"A__5!X?4M`.#N<>9E_JUMX?]SR%#V,6H*#@0`L?]Y:%%4K*#Y]?EH4
M.8QYF55>\#Y5?2@^?0I(>'V,^A15/_`^?2GP.'V,ZA1]24MX/YQ:@GTL2A2!
M@0`P?]U8>'UJ^#@[G'F9?ZI3>'T<0A0]C%J"@X$`-'T(4A15*B@^?4A2%#F,
M>9E5:/`^55TH/G_K2'A]C/(453[P/GTI0#A]C.H4?6E+>#^<6H)]+$H4@8$`
M.'T=4'A]2_`X.YQYF7^K6WA__/H4/8Q:@H.!`#Q__UH452LH/GU_6A0YC'F9
M55_P/E5]*#Y_RDAX?8Q"%%4H\#Y]*?@X?8SJ%'U)2W@_G%J"?2Q*%(&!`$!_
M_5AX?6I`.#N<>9E_JE-X?]SR%#V,6H*#@0!$?]Y2%%4J*#Y]7E(4.8QYF55^
M\#Y572@^?0M(>'V,^A15/_`^?2GP.'V,ZA1]:4MX/YQ:@GTL2A2!@0!(?]U0
M>'U+^#@[G'F9?ZM;>'T<0A0]C%J"@X$`3'T(6A15*R@^?6A:%#F,>9E52/`^
M57TH/G_J2'A]C/(453[P/GTI0#A]C.H4?4E+>#^<6H)]+$H4@8$`4'T=6'A]
M:O`X.YQYF7^J4WA__/H4/8Q:@H.!`%1__U(452HH/GU?4A0YC'F957_P/E5=
M*#Y_RTAX?8Q"%%4H\#Y]*?@X?8SJ%'UK2W@_G%J"?6Q:%(&!`%A__5!X?4E`
M.#N<>9E_J4MX?]SR%#V,6H*#@0!<?]Y*%%5I*#Y]/DH454KP/CF,>9E5/2@^
M?1Y8>'V,^A15?_`^?6M0.'V,ZA1_WEMX?5U(>'TK^#A_O5MX/YQ:@H%A`&`[
MG'F9?\SR%(&!`*A]'$(4/6MNVG^(ZA0Y"^NA5\LH/E4I\#Y]?%H4@X$`9'T]
M^GA]2%(45\CP/C^<;MI_OO)X?ZKR%#N<ZZ%]'DIX56HH/GU=4A1_G/H4@Z$`
M:%5_\#Y_RUIX?YQ:%%5+*#Y]?%H4/[UNVH.!`&Q__D)X.[WKH7^]2A0_G&[:
M54GP/G_*4GA_O5(4?3[Z>%5J*#X[G.NA?5U2%'^<0A2#H0!P56CP/G_+6GA_
MG%H454LH/GU\6A0_O6[:@X$`='T>2G@[O>NA?[WZ%#^<;MI57_`^?\I2>'^]
M4A1__D)X56HH/CN<ZZ%]75(4?YQ*%(.A`'A5:?`^?\M:>'^<6A152R@^?7Q:
M%#^];MJ#@0!\?3[Z>#N]ZZ%_O4(4/YQNVE5(\#Y_RE)X?[U2%'T>2GA5:B@^
M.YSKH7U=4A1_G/H4@Z$`@%5_\#Y_RUIX?YQ:%%5+*#Y]?%H4/[UNVH.!`(1_
M_D)X.[WKH7^]2A0_G&[:54GP/G_*4GA_O5(4?3[Z>%5J*#X[G.NA?5U2%'^<
M0A2#H0"(56CP/G_+6GA_G%H454LH/GU\6A0_O6[:@X$`C'T>2G@[O>NA?[WZ
M%#^<;MI57_`^?\I2>'^]4A1__D)X56HH/CN<ZZ%]75(4?YQ*%(.A`)!5:?`^
M?\M:>'^<6A152R@^?7Q:%#^];MJ#@0"4?3[Z>#N]ZZ%_O4(4/YQNVE5(\#Y_
MRE)X?[U2%'T>2GA5:B@^.YSKH7U=4A1_G/H4@Z$`F%5_\#Y_RUIX?YQ:%%5+
M*#Y]?%H4/[UNVH.!`)P[O>NA?_Y">'^]2A0_G&[:54GP/CN<ZZ%_RE)X?3[Z
M>'^]4A1_G$(456HH/E5H\#Y_RUIX@\$`H'U=4A1]'4IX?YQ:%#_>;MI52R@^
M.][KH7U\6A1__OH455[P/G^J4GB#H0"D/8QNVG^?4A1_WT)X/[UNVE5J*#X[
MO>NA?5Q2%(.!`*Q_O4H456GP/G_K6G@YC.NA?3_R>'^]6A152R@^?8Q"%'U]
M6A152/`^?^I2>%5_*#Y]C%(4?1U*>'_L^A2!@0"P/YQNVE5J\#X[G.NA/8R/
M''^K6G@YC+S<?5U`.'TL2A2!@0"T?]SR%'U<0WA_WEH4/8R/'%?K\#XYC+S<
M?YSX.'T,0A2!@0"X5_\H/G_>^A1_G^MX/8R/''U]4#@YC+S<?7Q3>'U,4A2!
M@0"\?YSP.'_I^A17R?`^/8R/'%?>*#XYC+S<?__R%'^>ZWA]/5@X?3Q;>'UL
M6A2!@0#`?YSX.'_(\A0]C(\<5^CP/CF,O-Q7_R@^?][Z%'^?ZWA]'4@X?1Q+
M>'TL2A2!@0#$?YSP.'_J^A17RO`^/8R/'%?>*#XYC+S<?__R%'^>ZWA]74`X
M?5Q#>'T,0A2!@0#(?YSX.'_+\A0]C(\<5^OP/CF,O-Q7_R@^?][Z%'^?ZWA]
M?5`X?7Q3>'U,4A2!@0#,?YSP.'_I^A17R?`^/8R/'%?>*#XYC+S<?__R%'^>
MZWA]/5@X?3Q;>'UL6A2!@0#0?YSX.'_(\A0]C(\<5^CP/CF,O-Q7_R@^?][Z
M%'^?ZWA]'4@X?1Q+>'TL2A2!@0#4?YSP.'_J^A17RO`^/8R/'%?>*#XYC+S<
M?__R%'^>ZWA]74`X?5Q#>'T,0A2!@0#8?YSX.'_+\A0]C(\<5^OP/CF,O-Q7
M_R@^?][Z%'^?ZWA]?5`X?7Q3>'U,4A2!@0#<?YSP.'_I^A17R?`^/8R/'%?>
M*#XYC+S<?__R%'^>ZWA]/5@X?3Q;>'UL6A2!@0#@?YSX.'_(\A0]C(\<5^CP
M/CF,O-Q7_R@^?][Z%'^?ZWA]'4@X?1Q+>'TL2A2!@0#D?YSP.'_J^A17RO`^
M/8R/'%?>*#XYC+S<?__R%'^>ZWA]74`X?5Q#>'T,0A2!@0#H?YSX.'_+\A0]
MC(\<5^OP/CF,O-Q7_R@^?][Z%'^?ZWA]?5`X?7Q3>'U,4A2!@0#L?YSP.'_I
M^A17R?`^/8R/'%?>*#XYC+S<?__R%'^>ZWA]/5@X?3Q;>'UL6A2!@0#P?YSX
M.'_(\A0]C(\<5^CP/CF,O-Q7_R@^?][Z%'^?ZWA]'4@X?1Q+>'TL2A2!@0#T
M?YSP.'_J^A17RO`^/8R/'%?>*#XYC+S<?__R%'^>ZWA]74`X?5Q#>'T,0A2!
M@0#X?YSX.'_+\A17Z_`^5_\H/G_>^A0]C(\<?Y_K>'U\4WA]?5`X?YSP.'_I
M^A0YC+S<5\GP/E?>*#Y___(4?4Q2%(&!`/Q_GNMX?3Q;>'T]6#A_G/@X?\CR
M%%?H\#Y7_R@^/8R/''_>^A1_G^MX?1U+>'^*^A1_O?`X?1](.#F,O-Q7RB@^
M?5Q2%'^_^WB#H0$`5][P/GUL6A1]B_H4?]]">%5+*#Y__U)X?6Q:%#^]RF-5
M3/`^@4$!!#N]P=9]/4H4/4K*8W^I^A0Y2L'6?8GR>%5_*#Y]"D(4?_WZ%%5J
M\#Y]*UIX@2$!"'^H6A17ZR@^?7U:%#TIRF.#H0$,?4AB>#DIP=9_R?(4/[W*
M8U?I\#Y]'_IX?][Z%%5H*#Y]/U)X.[W!UGT>0A1_O6(4@\$!$%5L\#Y_ZUIX
M?[U:%%4+*#Y]?5H4/][*8X.A`11]GTIX.][!UG_>4A0_O<IC50KP/G_H0GA_
MWD(4?5]B>%5H*#X[O<'6?1Y"%'^]2A2#P0$856GP/G_K6GA_O5H450LH/GU]
M6A0_WLIC@Z$!''T_4G@[WL'6?]YB%#^]RF-5#/`^?^A">'_>0A1]GTIX56@H
M/CN]P=9]'D(4?[U2%(/!`2!5:O`^?^M:>'^]6A15"R@^?7U:%#_>RF.#H0$D
M?5]B>#O>P=9_WDH4/[W*8U4)\#Y_Z$)X?]Y"%'T_4GA5:"@^.[W!UGT>0A1_
MO6(4@\$!*%5L\#Y_ZUIX?[U:%%4+*#Y]?5H4/][*8X.A`2Q]GTIX.][!UG_>
M4A0_O<IC50KP/G_H0GA_WD(4?5]B>%5H*#X[O<'6?1Y"%'^]2A2#P0$P56GP
M/G_K6GA_O5H450LH/GU]6A0_WLIC@Z$!-'T_4G@[WL'6?]YB%#^]RF-5#/`^
M?^A">'_>0A1]GTIX56@H/CN]P=9]'D(4?[U2%(/!`3A5:O`^?^M:>'^]6A15
M"R@^?7U:%#_>RF.#H0$\?5]B>#O>P=9_WDH4/[W*8U4)\#Y_Z$)X?]Y"%'T_
M4GA5:"@^.[W!UGT>0A1_O6(4@\$!0%5L\#Y_ZUIX?[U:%%4+*#Y]?5H4/][*
M8X.A`40[WL'6?9]*>'_>4A0_O<IC50KP/CN]P=9_Z$)X?5]B>'_>0A1_O4H4
M56@H/E5I\#Y_ZUIX@^$!2'T>0A2#P0%,?[U:%%4+*#X__\IC?\#R%#O_P=9]
M(%)X?7U:%'V?8A0_WLIC51_P/GP(0G@[WL'6?8Q"%%5@*#Y_Z$IX?5Y2%'P,
M`A1]"%IX?0I"%%5K\#Y4"B@^?*7Z%'U(4A1\!@(4?.=:%'TD2A210P``D`,`
M!(.!`5"#H0%4D.,`")"C``R#P0%8@^$!7#@A`6"1(P`03H``(&````!@````
M8````)0A_]!\"`*FDX$`()-A`!Q\?!MYDT$`&)`!`#1\FB-XDZ$`))/!`"B3
MX0`L0((`-#A@``"``0`T@T$`&(-A`!R#@0`@?`@#IH.A`"2#P0`H@^$`+#@A
M`#!.@``@8````#T@$`*#:;U4+YL``$&>_\2('```+X```$&>`)@O@``]09X`
MD'^=XWB,'0`!+X```"\``#U!G@`(0)K_\'^\Z%"#^P``+Y\``$&>_XA_?MMX
M?^/[>'^$XWA_I>MX2``MA2^#``!`G@`0?!_HKB^``#U!G@`@A_X`!"^?``!`
MGO_42___4&````!@````8````'_;\%`X?0`!?]X6<)/:``!\?QH42___,&``
M``!@````.Z```$O__XQ@````8````)0A_^!\"`*FD`$`)#B!`!Q,QC&"2__^
MS8`!`"0X(0`@?`@#IDZ``"!@````8````)0A_^!\"`*FD^$`')`!`"0_X!`"
M@'^]."^#__]!G@`D@`$`)(/A`!PX(0`@?`@#IDZ``"!@````8````&`````\
M8!``.&-:^$S&,8)+__^%+`,``$&"`#R(8P``+X,``$&>`#!H8P`P?&,`T%1C
M#_Z0?[TX@`$`)(/A`!PX(0`@?`@#IDZ``"!@````8````#A@``"0?[TX2___
MW&````"4(?_0?`@"II.A`"23P0`H/Z`0`GQ^&WB3X0`LD`$`-#N]O50[X0`<
M2```*&````"!(0`<@!T``%4I$#I]($H4A`D`!)`)__PO@```0)[_]'_#\WA_
MY/MX3,8Q@DO__;4O@P``0)[_S(`!`#2#H0`D@\$`*(/A`"PX(0`P?`@#IDZ`
M`"!@````8````&````"4(>_0/&`0`'P(`J8X8UL$DX$0().A$"1\O"MX?)TC
M>)/!$"B3X1`L.*`/_Y`!$#0[P0`<?\3S>(`"C_B0`1`<.````$@`*PTL`P``
M0($`I#@!$"`[X___?2#Z%(@)[_PO@```09X`?'Q_&WA_P_-X.(``+W_E^WA(
M`"LY+X,``$&>`'`X8```2``KB8!C``!(`"AQ?Z3K>'_%\WA_YOMX2``IP8$A
M$!R``H_X?2D">3@```!`@@!<@`$0-(.!$""#H1`D@\$0*'P(`Z:#X1`L."$0
M,$Z``"!@````8````"^?``!`GO^(8````&`````X8```2``K'8!C``!(`"@%
M?Z3K>'^%XWA(`"?92___F$@`*?%@````8````&````"4(?_P.&```'P(`J:0
M`0`42``JX8!C``!(`"?).(#__T@`*!$X8```2``JR8!C``!(`">Q/(`0`#B@
M```XA"V`2``K(8`!`!0X(0`0?`@#IDZ``"!@````8````&````"4(?_@.&``
M`'P(`J:3X0`<D`$`)$@`*GV`8P``2``G94@`)A&!(P``.&```(/I``1(`"IA
M@&,``$@`)TE(`":5B`,``#A@``"8'P`82``J18!C``!(`"<M2``EV8$C```X
M8```@^D`!$@`*BF`8P``2``G$4@`)FV!(P``.&```(`)`!!4`$W^L!\`&D@`
M*@6`8P``2``F[4@`)9F!(P``.&```(/I``1(`"GI@&,``$@`)M$\@!``.*``
M`#B$7#!(`"EAD'\`'#A@``!(`"G%@&,``$@`)JU(`"59@2,``#A@``"#Z0`$
M2``IJ8!C``!(`":12``EO8`#```X8```D!\`($@`*8V`8P``2``F=4@`)2&!
M(P``.&```(/I``1(`"EQ@&,``$@`)EE(`"B%.````($C```OB0``09X`(#A@
M``!(`"E-@&,``$@`)C5(`"AA@2,``(`)`&R0'P`D.&```#O@``!(`"DI@&,`
M`$@`)A%(`"2]@2,``#A@``"!*0`$D^D`*$@`*0F`8P``2``E\4@`))V!(P``
M.&```($I``23Z0`L2``HZ8!C``!(`"712``D?8$C```X8```@^D`!$@`*,V`
M8P``2``EM4@`*)&``P``D!\`,(`!`"2#X0`<."$`('P(`Z9.@``@E"'_8'P(
M`J:3X0"<D\$`F'Q_&WF0`0"DDT$`B)-A`(R3@0"0DZ$`E$&"`!"('P``+X``
M`$">`"R``0"D@T$`B(-A`(R#@0"0?`@#IH.A`)2#P0"8@^$`G#@A`*!.@``@
M2``EP7Q^&WE!@O_0/V`0`#N!`!@[>UL48````&````!_P_-X2``F#7QZ&WE_
MX_MX08(`H(@:`!,[6@`3+X``+D&>`-!(`"8=?'T;>']#TWA(`"81?'T:%#AC
M``)(`":U?V3;>'_E^WA_1M-X?'T;>$S&,8)(`"@M?X7C>'^DZW@X8``#2``C
M[2^#__]_H^MX09X`%(`!`"A4``0F+X!``$&>`*!(`"7-?Z/K>$@`),5_P_-X
M2``E?7QZ&WE_X_MX0(+_=&````!@````8````'_#\WA(`"7M?^/[>$@`)F6`
M`0"D@T$`B(-A`(R#@0"0?`@#IH.A`)2#P0"8@^$`G#@A`*!.@``@8````&``
M``"(&@`!+X```$&>_P@O@``N0)[_)(@:``(O@```09[^]$O__Q1@````8```
M`&````!+__YA2___9&````!@````E"'_X'P(`J:3X0`<D`$`)'Q_&W@X8```
M2``FV8!C``!(`"/!2``E_7_D^WA\91MX.&```T@`)`TO@P``09X`)(`!`"2#
MX0`<.&```#@A`"!\"`.F3H``(&````!@````2``FD8!C``!(`"-Y2``EM8`#
M`!!4``0F+X!``$&>`"PX8```2``F;8!C``!(`"-52``ED8$C`!!5*00F;2#_
M_R^`H`!`GO^<?^/[>#B```)(`".A@`$`)(/A`!PX(0`@?`@#IGQC`#148]E^
M3H``()0AW]!\"`*FD^$@+)/!("B0`2`TDZ$@)#OA$!N``H_XD`$@'#@```!(
M`"&I/(`0`#S`$`!\91MX.(1;'#C&6RA_X_MX3,8Q@D@`)CDO@P``0)P`0#O@
M``"!(2`<@`*/^'TI`GDX````?^/[>$""`&B``2`T@Z$@)(/!("B#X2`L."$@
M,'P(`Z9.@``@8````#O!`!I_X_MX?\3S>#B@$`!(`"3!?'T;>4&`_ZPX?0`!
M2``D07Q_&WE!@O^@?\3S>'^EZWA(`"-=.````'P?Z:Y+__^(2``D/6````!@
M````E"'_\#@A`!!+__\88````)0A_\!\"`*FDX$`,).A`#1\?1MXD\$`.)/A
M`#R0`0!$DR$`))-!`"B380`LB`0``&@?`#TC_P``?^0!E'_C^WA(`",1.($`
M''Q\&WA_H^MX3,8Q@DO_]DU\?AMY08(`9$@`(O$Y(```?YP80$&=`@!\'TBN
M?!Y)KCDI``$O@```0)[_\(`!`$2#(0`D.&```(-!`"B#80`L?`@#IH.!`#"#
MH0`T@\$`.(/A`#PX(0!`3H``(&````!@````8````#]@$`([P```.(``"(![
MO51\:1MX@`,``"^```!!G@`<A`D`!#O>``$O@```0)[_]#B>``)4A!`Z/2`0
M`H`)O7PO@```09X`3$@`(#E7V1`Z+X,``'QZ&WB0>[U40)X`8(`!`$2#(0`D
M.&#__X-!`"B#80`L?`@#IH.!`#"#H0`T@\$`.(/A`#PX(0!`3H``(#@```%\
M@R-XD`F]?$@`(J5\>AMY08+_O%?9$#J`F[U4?R7+>$@`(PV36[U4.!X``3D@
M``!4`!`Z?3H!+I/!`!R('0``+X```$&>`.0O@``]09X`W'^IZWA(```,8```
M`$&:`!2,"0`!+X```"\``#U`GO_P?3U(4#A\``*#V[U4?&-*%$@`(BTO@P``
M?'[)+D&>_T`](!`"B!T``"^```"!:;U4@2$`'%4I$#I]*T@NF`D``$&>`#@O
M@``]09X`,#N]``%(```08````&````!!F@`<B!T``#N]``&<"0`!+X```"\`
M`#U`GO_H.```/3E@``"8"0``8````&````!\'UBN?4E:%#EK``$O@```F`H`
M`4">_^Q+__X<@R$`'#]@$`)7.1`Z2___&#D@``!+__](8````&````!@````
M/2`0`)0A_[`Y*5IL?`@"II/A`$R3P0!(D`$`5).A`$1\?1MX@^D`!(`)`!B3
M`0`PDR$`-(#I``B!"0`,DT$`.)-A`#R!20`0@6D`%).!`$"0X0`<D0$`()%!
M`"2180`HD`$`+)/A`!B('P``+X```$&>`(@_8!``@XD`'#O!`!P[>ULL2```
M+&````!@````2``@P2^#``!!G@"8@_X``#O>``2('P``+X```$&>`$Q_X_MX
M3,8Q@DO_]'E_I.MX?'D;>4&"`!"(&0``+X```$">_\!_X_MX?Z3K>$S&,8)+
M__R1@_X``#O>``2('P``+X```$">_[R``0!4@P$`,(,A`#2#00`X?`@#IH-A
M`#R#@0!`@Z$`1(/!`$B#X0!,."$`4$Z``"!@````8````'^CZWA(`!^-?'@;
M>'^#XWA(`!^!?'H;>'\CRWA(`!]U?3C2%#@)``%\8!H42``@%7]DVWA_I>MX
M?X;C>'\GRWA\>AMX3,8Q@D@`(8E_X_MX?T33>$S&,8)+__OI2___$)0A_[`\
M@!``?`@"ICB$6FPXH``BDX$`0).A`$0XA``@/Z`0`)/!`$B3X0!,/^`0`#N]
M6WB0`0!4._];7#_`$``[WEKX/X`0`#N<6X0X80`:@`*/^)`!`#PX````2``>
MM3Q@$``X8ULT3,8Q@DO_]`4\8!``.&-;0$S&,8)+__/U/&`0`#AC6TA,QC&"
M2__SY3Q@$``X8UM43,8Q@DO_\]5_X_MX3,8Q@DO_\\D\8!``.&-;;$S&,8)+
M__.Y?Z/K>$S&,8)+__.M?\/S>$S&,8)+__.A?X/C>$S&,8)+__.5/&`0`#AC
M6Y!,QC&"2__SA3Q@$``X8UN<3,8Q@DO_\W4\8!``.&-;K$S&,8)+__-E/&`0
M`#AC6[A,QC&"2__S53Q@$``X8UO$3,8Q@DO_\G5\9!MY08(`$'^#XWA,QC&"
M2__ZH3Q@$``X8UO83,8Q@DO_\E%\9!MY08(`%#Q@$``X8UOL3,8Q@DO_^GD\
M8!``.&-;^$S&,8)+__(I?&0;>4&"`&!_H^MX3,8Q@DO_^E4\@!``?^/[>#B$
M7"A,QC&"2__Z08$A`#R``H_X?2D">3@```!`@@",@`$`5(.!`$"#H0!$@\$`
M2'P(`Z:#X0!,."$`4$Z``"!@````8````#Q@$``X8UP(3,8Q@DO_\;5\9!MY
M08(`''_#\WA,QC&"2__YX4O__XQ@````8````#R`$``X80`K.(1<'#B@``I(
M`!ZA+X,``$">_VA_P_-X.($`-4S&,8)+__FI2___5$@`'<%@````8````&``
M``"4(?_P?`@"II`!`!1(`!T52``<\3@````L`P``08(`"(`#``!\`P-X@`$`
M%#@A`!!\"`.F3H``(&````!@````E"'_X'P(`J:3P0`8D^$`''Q^&WF0`0`D
M08(`J(@>```O@```09X`G$@`''D]0!``.`/__WR^`A1_GBA`0)P`2($J6FQ]
M?@"NB2D``'^+2`!`G@"@?'X:%'P>*%`X8__^?YX80'P)`Z9`O0`42``!>(@%
M``!_@%@`0)X`>#BE__]"`/_P?X7P`$">`*2`:EILB24``(@#``!_B0``09X!
M!$@`'B&``0`D@\$`&(/A`!PX(0`@?`@#IDZ``"!@````.&```D@`'(TL`P``
M08(`##@`+@"P`P``@`$`)(/!`!B#X0`<."$`('P(`Z9.@``@.`7__W^>`$!\
M'BA0?`D#ID&=`-@OGO__0+X`%$@``,R(!0``?X!(`$&>_VPXI?__0@#_\'^%
M\`!!GO]D.`7__X%J6FQ_G@!`?!XH4'P)`Z9!G0",+Y[__T&>`(1@````.*7_
M_T)``!2("P``B24``'^)``!!GO_L?+XH4#@%``(K@!``09T`/#_@$`)_Q/-X
M._^]?#BE``$[_P`$?^/[>$@`&5%_X_MX2___0&`````X8``"2``;K2P#``!`
M@O\D@`$`)(/!`!@X8```@^$`'#@A`"!\"`.F3H``(#@```%\"0.F2___?#@`
M``%\"0.F2___/#@```%\"0.F2__^D)0A_^!\"`*FD\$`&)/A`!Q\?AMXD`$`
M)$O__?F(`P``?'\;>"^```!!G@!$/2`0`#AC``&!*5ILB2D``$@``!2(`P``
M.&,``2^```!!G@`@?X!(`$">_^R(`P``?'\;>#AC``$O@```0)[_Z$O_[N4O
M@P``09X`,"^>``!!G@`HB!X``"^```!!G@`</(`0`'_C^W@XA%PL2``:J7^?
M&`!!G@`<@`$`)(/!`!B#X0`<."$`('P(`Z9.@``@@`$`)(/A`!Q_P_-X@\$`
M&#@A`"!\"`.F2__S'&````!@````E"'_T'P(`J:080`<D($`&)"A`!20`0`T
MD^$`+)/!`"@X80`<.($`&#BA`!1(`!MU/(`0`#Q@$``XA%0`.&-5T'R%(WA(
M`!5=.&```$@`&(6+XP``+Y\``$">`#1(`!AE/2`0`B^#``"0:<V`09X"0$@`
M&2$X8```2``;.8!C``!(`!@A2``:G9OC```X8```2``;(8!C``!(`!@)2``;
M)7QI&W@X8```B`D``&````*8"0``2``:_8!C``!(`!?E2``;`3T@$`#`"5KD
M/2`0`(@#``!@```!F`,``#P`0S"0`0`(@&$`'#AC``6080`,R:$`"/VM`"C(
M"5KH/2`0`/VM`"K("5KP_XT``$&=`8@_X!`"5&,0.CO_O7Q(`!H5@0$`&("A
M`!P]8!``+X4``7QI&WB0?Q`(@`@``)`#```X"UPT/6`0`)`#``0X"UZ(/6`0
M`)`#``@X"UPXD`,`##@```20'Q`,0)T`+#@%__\Y8``$?`D#IF````!@````
M?4E:%'P(6"XY:P`$D`H`#$(`__`XI0`#.6```(!_$`14H!`Z/(`0`'TF2W@X
MA%&0..```'UI`2Y(`!79?'X;>4&"`%"`?Q`$2``8B3Q@$``X8UML3,8Q@DO_
M[&DO@P``09X`7(!_$`1(`!692``758`!`#2#X0`L?\/S>(/!`"@X(0`P?`@#
MIDZ``"!@````@'\0!$@`%BU\?AMX@'\0!$@`&#$\8!``.&-;;$S&,8)+_^P1
M+X,``$">_ZR`?Q`0+X,``$&>`#!+__S9@'\0!$@`%3%(`!;M@`$`-(/A`"Q_
MP_-X@\$`*#@A`#!\"`.F3H``(#Q@$``X8UMX3,8Q@DO_Z\$O@P``D'\0$$&>
M_UA+__^X/&`0`#R`$`(X8UT$.(2]8$S&,8)(`!AI.&```4@`&5%@````8```
M`&````!]@``FE"'OL'P(`J:381`\DX$00).A$$23P1!(?'T;>#Q@$`"3X1!,
MD8$0(#AC6WA\GB-XD`$05)*A$"22P1`HDN$0+),!$#"3(1`TDT$0.(`"C_B0
M`1`<.````$S&,8)+_^LA/2`0`#N)6FQ\>QMX@^E:;'^CZWA_Y/MX2``7)2^#
M``!!G@!T/&`0`'^DZW@X8UN<3,8Q@DO_\RF!(1`<@`*/^'TI`GDX````?Z/K
M>$""`=2``1!4@8$0((*A$"2"P1`H?`@#IH+A$"R#`1`P?8"!((,A$#2#01`X
M@V$0/(.!$$"#H1!$@\$02(/A$$PX(1!03H``('^CZWA(`!85@UP`''QY&WA_
M1--X?\/S>$@`%O%\=1MY08+_<#[@$``_`!``.L```#KW7#P[.0`!.QA;+&+6
M@``N&P``.X$`'#O```!@````8````&````"(%0``+X```$">``A^];MX09(`
M&']CVWA^I*MX2``7I2^#``!!G@#`?J.K>$@`%96('P``?34:%(EI__]_BP``
M0)X`+&````!@````8````'TK2WB?R?__.&/__XEK__Z('P``?XL``$&>_^A\
M>1H4+X,/_T&=_L1^I:MX?P3#>'_F^WA_I^MX?X/C>$S&,8)(`!=Q.&```$@`
M%PF`8P``2``3\4@`%BU_A.-X?&4;>#A@``-(`!,=+X,``$">`"1(`!;A@&,`
M`$@`$\E(`!8%@`,`$%0`!"9_@+``09X`(#A@``!_1--X2``5R2^#``!\=1MX
M0)[_#$O__D!_@^-X.(```4@`$_TO@P``0)[_U#Q@$`!_A.-X.&-;G$S&,8)+
M__%1?X/C>$@`%KE\?1MX2__^'$@`%5U@````8````#P`__]\+`MX8`!^<'PA
M`6Y\"`*FD`P`!)(L_\0^(0`!DRS_Y)-,_^@_(!``DVS_[).,__`_@!``.SE;
M>).L__23S/_X.3Q:;)/L__R23/_(.^&!4))L_\R2C/_0@*D`=(-I`$B#R0!0
M@,D`5(#I`%B!"0!<@4D`8(%I`&2`"0!H@(D`;(.I`$R#20!$DJS_U)+,_]B2
M[/_<DPS_X($I`'""0H_XDE&!3#I```"37W]`DW]_1'Q[&WB3WW],D[]_2'\C
MRWB0GW]0D3]_5)"_?UB0WW\HD/]_+)$??S"17W\TD7]_.)`??SQ,QC&"2__H
M!7Q^&WE!@@`0B!X``"^```!`G@3`2__VG7QZ&WE!@@34B]H``"^>``!!G@`\
M2``2Y7])TW@Y0`!?8````&````"!8P``5]X(/'P+\BYP%P@`0((`")E)``"/
MR0`!+YX``$">_^"`?W\HB`,``"^```!!G@/`.\```4@``#1@````.P```%?)
M$#IC&(%0.]X``7\8"A1].$H4/2G__X!I?RB(`P``+X```$&>`XA,QC&"2__G
M47Q]&WE!@O_(2__MQ2^#``!!GO^\?Z/K>$@`%.5\>!MY08+_K'\#PWA(`!*U
M?'T;>']#TWA(`!*I?[T:%#N]!`1_H^MX2``327Q^&WA_H^MX2``3/8.<6FP\
M@!``/.`0`#B$7$!_!<-X?'T;>#CG7"Q_2--X?X;C>$S&,8)(`!2A?Z/K>#B`
M`<!(``_U+X/__T&>`APX8``#?Z3K>#B_?L!(`!%M+X/__T&>!_R`'W[05``$
M)B^`0`!`G@(T@U]^V$@`$EU_FA@`0)X")(`??M!4``7^+X`!P$">`A0\8!``
M.&->;$S&,8)+_^9E+X,``$&>`\"#6P``2``4!7QD&WA_0]-X2__ZR7QZ&WE!
M@@.D?T/3>$@`$<DO@P`#?'@;>$"=`'PX8__\/(`0`'QZ&A0XA%SH2``3J2^#
M``!`G@!@+Y@`!$&>`!A_&L(4B!P``(DX__M_B0``0)X`1(-[``0OFP``09X`
M.']CVWA(`!%Q*X,``T"=`"@X8__\/(`0`'Q[&A0XA%SP2``352^#``!!G@`0
M8````&````!_6]-X2__EW7_8\W@O@P``0)X`'']CVW@X@```3,8Q@D@`$L%\
M>QMY0(("]#R`$``\8!``.(1<*#AC6OA,QC&"2__ML3]@$``_0!``2``.A3M[
M7#`\@!``.(1=$'^EZWA\9QMX?X;C>'_#\WA_:-MX3,8Q@D@`$PT[6ET@.^``
M`$@``$Q@````8````&````!(``XA@`,``"^``!%`G@!$2``.,3O_``%_1--X
M?Z7K>'^&XWA\9QMX?^C[>'_#\WA_:=MX3,8Q@D@`$KE_P_-X.(`!P$@`#@TO
M@___09[_M'^CZWA(``]M?R/+>'_$\WA,QC&"2__L_7_#\WA+_^^%2```=&``
M``!@````8````$@`#:&`XP``+X<`$4&>_=P](!`"@+L``#R`$``XA%Q,?Z;K
M>#L```"`:;U03,8Q@D@`$*%(```P8````&`````](!`"@+L``#R`$``XA%S`
M?Z;K>#L```"`:;U03,8Q@D@`$'$\P0`!?P/#>(#F@4R`PH_X?.<R>3C```!`
M@@8L@6$``(`+``2"*__$@DO_R()K_\Q\"`.F@HO_T(*K_]2"R__8@NO_W(,+
M_^"#*__D@TO_Z(-K_^R#B__P@ZO_](/+__B#Z__\?6%;>$Z``""#WW]`.Z``
M`8@>```O@```0)X`/$@``(1@````8````#@```!7J1`Z8`"!4#N]``%\``H4
M?2!*%#TI__^#R7]`B!X``"^```!!G@!0?\/S>$O_Z@$O@P``09[_R'_#\WA(
M`!$A?'@;>4""_$`X````5ZD0.F``@5`[O0`!?``*%'T@2A0]*?__@\E_0(@>
M```O@```0)[_N#L```!+__P,2__N`7_#\WA(`!#9?'@;>$O__N1@````8```
M`&````"`?W]0B`,``"^```!!G@!<.\```6````!@````8````$S&,8)+_^+M
M+X,``$&>`!!(`!"1?'H;>4""^O@Z8```5\D0.F)S@5`[W@`!?G,*%'TS2A0]
M*?__@&E_4(@#```O@```0)[_O#]`$``[6ETT2__[!(-;``!+__Q<.*#__SC`
M_^XXX``".U]_7$@`#'5_8]MX?T33>#B@``9(``SEB!]_7"^```!`G@`0B!]_
M72^``$-!G@/D.,```#C@``!_8]MX.*```$@`##D\P0`!/2!G16$I(P$X````
M..```#D```"1)H"LD`:`P#T@[\U@YX"L82FKB9`&@,20!H$(80B`R)$F@+`]
M()BZ.I]_7&$IW/Y^H3H4D2:`M#T@$#)^P4(482E4=I$F@+@](,/282GA\)$F
M@+Q@````8````#B@``!_8]MX8*6``'Z$HWA(``PQ?'\;>4"!`1@]00`!5^`8
M.($J@,!\`$H4?XD`0$&=`/"!*H#$/D$``5?K'WY]*5H4?I>C>(!R@0B0$H#`
MD3*`Q"^#``!!G@!8(`,`0'_W^WA_GP``0)T`"'P7`W@^80`!?'8:%'Z$HWA^
MY;MX2``,P8`3@0A\%P(4+X``0)`3@0A`GO]L?J.K>'_W^%!^]+H42__1O6``
M``!@````+Y\`/T"=`%`[0```8````'R7TA0XH`!`?L.S>#M:`$!(``QQ?J.K
M>$O_T8E\&OA0+X``/T&=_]P[___`5^G1OC@)``%5*3`R5``P,G[W`A1_Z?A0
M?N2[>#[A``%^P[-X?^7[>$@`#"V3]X$(2__^Y#XA``&!,8#$.2D``4O__PQ_
M8]MX2``,G3S!``$XX```8.>!4'SG"A2#YH#`@V:`Q%?I[KY]9TH4.`D``2^`
M`#@Y(/^`F2O_>$&=`91\=@(4(*``.#B```!(``J)/B$``3Y!``%79T8^5VB$
M/E=JPCY7ZT8^5^F$/E?@PCY^HZMXF/&!`)D1@0&948$"FW&!`YEQ@029,8$%
MF!&!!IOQ@0=+_]"A/B$``8%2@+"!<H"T@3*`N(`2@+R!$H"L57>$/E4_A#Y5
M$H0^51/"/II1@3F:<8$Z.D```#I@``!B4H$/579&/E5ZPCY5.T8^505&/E5,
M1CY55(0^557"/E4CPCY4!$8^5`:$/E0'PCZ:\8%!FM&!0#[@$`!B<X$XF_&!
M19MQ@41_X9(4.O==")M1@4*9<8%#?_K[>#M@``"9$8$[F9&!/'[!FA2:D8$]
MFK&!/IE1@3^8<8%&F3&!1YB1@4B8T8%)F/&!2I@1@4N8L8$X2```%&````!@
M````8````'RVV*Y_0]-X?N2[>$S&,8)(``SQ+YL`$SM:``([>P`!0)[_X#[A
M``$X````/(`0`#T`$``XA%SX?X;C>)@7@3=_Y_MX.0A<,'_#\WA_I>MX3,8Q
M@D@`#*U+__H((*``0#B```!\=@(42``(^7ZCJWA+_\]1?L.S>#B````XH``X
M2``(X4O__EA(``>I/2`0`H"[```\@!``.(1<B'^FZWB`XP``.P```(!IO5!,
MQC&"2``*L4O_^D"('W]>+X``04">_!B('W]?+X``0T">_`R('W]@+X``2$">
M_`"('W]A+X``14">^_0XP/_&..```CB@__]_8]MX2``(*7]$TWA_8]MX.*``
M*4@`")D\@!``/0`0`#B$7/A_AN-X?T?3>#D(7#!_P_-X?Z7K>$S&,8)(``O1
M2__Y+$@`"EE@````E"'_T#A@``!\"`*FDT$`&)-A`!R0`0`TDX$`().A`"23
MP0`HD^$`+$@`"SF`8P``2``((4@`")TX```!F`,``#Q@$``X8UM<3,8Q@DO_
MW:4L`P``08(`$(@#```O@``Q09X"@$O_Z>TX8```2``*]8!C``!(``?=/(`0
M`#B@``$XA%T\.,``"T@`!XDL`P``08("D#^@$`*!8P`,.\```#N]O7P[X``!
M@3T0#(-K`!@OB0`!09T`-$@``*Q@````@(D`#'^#XWA(``JY+X,``$">`)"!
M/1`,._\``3O>``%_B?@`0)T`@#A@``!(``IU@&,``$@`!UU_9-MX?\7S>#C`
M``!(``C-?'H;>4&"`%2!.@``@5T0"%?K$#J`"0`(?XI8+G`+!`!`@O^8.&``
M`$@`"C&`8P``2``'&8":```XH```.,```D@`"IE\9!MX?X/C>$@`"BTO@P``
M09[_>($]$`PX"?__?X#P`$&>`>0X8```2``)[8!C``!(``;5/(`0`#B@``$X
MA%U$.,``!4@`!H%\?QMY08(`/#A@``!(``G!@&,``$@`!JF!/P`,/*`0`#BE
M74B`B0``2``&=8$_``R!*0``@`D`"'0)`$!`@@%@.&```$@`"8F`8P``2``&
M<3R`$``XH``!.(1=4#C```5(``8=?'\;>4&"`#P\8!``.&-;G$S&,8)+_]OE
M?'X;>4&"`7PX8```2``)18!C``!(``8M@3\`#'_%\WB`B0``2``%_3A@``!(
M``DE@&,``$@`!@U(``:).````'QI&W@X8```F`D``$@`"06`8P``2``%[4@`
M"2DX````D`,``#Q@$``X8UMX3,8Q@DO_VW$O@P``D'T0$$&>`40X@`'M2``$
MC7QF&WE!@@`4+X8`$4&>``POAO__0)X!"(`!`#2#00`8@V$`'(.!`"!\"`.F
M@Z$`)(/!`"B#X0`L."$`,$Z``"!@````8````(@#``$O@```0)[]?#A@``!(
M``AQ@&,``$@`!5D\@!``.*```3B$73PXP``+2``%!2P#``!`@OV`8````&``
M```_H!`".[V]?$O__DA@````.&```$@`""V`8P``2``%%8$_``R`B0``2``&
M^4O__H@OB0`!0)W^'#O@``%@````.&```#O_``%(``?Y@&,``$@`!.%_9-MX
M2``$B8`=$`Q_@/@`09W_W$O__>A@````2``'T8!C``!(``2Y@7\`#($]$`B`
MBP``@*D``$O_VZ5+__Z(@3T0"("]$!`\8!``.&-=A(")``!,QC&"2``&]8!]
M$`A+__$MD'T0$($_``R!*0``@`D`"'`+!`!!@@!,@&D`#("=$`A(``5Y@3\`
M#(%]$`A\?AMX@2D``(.K``"`"0`(<`L$`$&"`$B`J0`,/&`0`'^DZW@X8UU4
M?\;S>$S&,8)(``:-.&```$@`!R6`8P``2``$#8$_``PXH```.,```H")``!(
M``>)2___F#A@``!(``;]@&,``$@``^6!/P`,.*```#C```*`B0``2``'87QE
M&WA+__^88````)0A__`X8```?`@"II`!`!1(``;!@&,``$@``ZD\@!``/*`0
M`#S`$``XA%W4.*55P#C&7?!(``9]@`$`%#@A`!!\"`.F3H``(&````!@````
ME"'_\#A@``!\"`*FD`$`%$@`!G&`8P``2``#64O__Y4X8```2``&78!C``!(
M``-%/,`0`#R`$``XQEPP/*`0`#B$7?PXI4RP?,<S>#D```!(``0!@`$`%#@A
M`!!\"`.F3H``(````````````````'P(`J9"GP`%E"'_\#C```"3P0`(D`$`
M%'_(`J8_W@`".][HR($^@``OB0``09X`"(#)``!(``)-@`$`%(/!``@X(0`0
M?`@#IDZ``"``````3H``(&````!@````8````)0A_]!\"`*F0I\`!9/!`"B3
MH0`DDR$`%)-!`!A\N2MX?)HC>)-A`!R3@0`@?'L;>)`!`#23X0`L?\@"IC_>
M``([WNAH2__&68.^@`2#GH``?YW@4'^<%G%!@@`P.^```%?@$#I_8]MX?T33
M>'\ERW@[_P`!?!T`+GP)`Z9.@`0A?Y_@0$&<_]R``0`T@R$`%(-!`!B#80`<
M?`@#IH.!`""#H0`D@\$`*(/A`"PX(0`P3H``(````````````````)0A__!\
M"`*FD`$`%)/A``P_X!`"._^ZP(`?__PO@/__09X`)#O___Q@````8````'P)
M`Z9.@`0AA!___"^`__]`GO_P@`$`%(/A``PX(0`0?`@#IDZ``"!@````8```
M`)0A__!\"`*FD`$`%(`!`!0X(0`0?`@#IDZ``"``````/6`0`H%KN^Q]:0.F
M3H`$(#U@$`*!:[OP?6D#IDZ`!"`]8!`"@6N[]'UI`Z9.@`0@/6`0`H%KN_A]
M:0.F3H`$(#U@$`*!:[O\?6D#IDZ`!"`]8!`"@6N\`'UI`Z9.@`0@/6`0`H%K
MO`1]:0.F3H`$(#U@$`*!:[P(?6D#IDZ`!"`]8!`"@6N\#'UI`Z9.@`0@/6`0
M`H%KO!!]:0.F3H`$(#U@$`*!:[P4?6D#IDZ`!"`]8!`"@6N\&'UI`Z9.@`0@
M/6`0`H%KO!Q]:0.F3H`$(#U@$`*!:[P@?6D#IDZ`!"`]8!`"@6N\)'UI`Z9.
M@`0@/6`0`H%KO"A]:0.F3H`$(#U@$`*!:[PL?6D#IDZ`!"`]8!`"@6N\,'UI
M`Z9.@`0@/6`0`H%KO#1]:0.F3H`$(#U@$`*!:[PX?6D#IDZ`!"`]8!`"@6N\
M/'UI`Z9.@`0@/6`0`H%KO$!]:0.F3H`$(#U@$`*!:[Q$?6D#IDZ`!"`]8!`"
M@6N\2'UI`Z9.@`0@/6`0`H%KO$Q]:0.F3H`$(#U@$`*!:[Q0?6D#IDZ`!"`]
M8!`"@6N\5'UI`Z9.@`0@/6`0`H%KO%A]:0.F3H`$(#U@$`*!:[Q<?6D#IDZ`
M!"`]8!`"@6N\8'UI`Z9.@`0@/6`0`H%KO&1]:0.F3H`$(#U@$`*!:[QH?6D#
MIDZ`!"`]8!`"@6N\;'UI`Z9.@`0@/6`0`H%KO'!]:0.F3H`$(#U@$`*!:[QT
M?6D#IDZ`!"`]8!`"@6N\>'UI`Z9.@`0@/6`0`H%KO'Q]:0.F3H`$(#U@$`*!
M:[R`?6D#IDZ`!"`]8!`"@6N\A'UI`Z9.@`0@/6`0`H%KO(A]:0.F3H`$(#U@
M$`*!:[R,?6D#IDZ`!"`]8!`"@6N\D'UI`Z9.@`0@/6`0`H%KO)1]:0.F3H`$
M(#U@$`*!:[R8?6D#IDZ`!"`]8!`"@6N\G'UI`Z9.@`0@/6`0`H%KO*!]:0.F
M3H`$(#U@$`*!:[RD?6D#IDZ`!"`]8!`"@6N\J'UI`Z9.@`0@/6`0`H%KO*Q]
M:0.F3H`$(#U@$`*!:[RP?6D#IDZ`!"`]8!`"@6N\M'UI`Z9.@`0@/6`0`H%K
MO+A]:0.F3H`$(#U@$`*!:[R\?6D#IDZ`!"`]8!`"@6N\P'UI`Z9.@`0@/6`0
M`H%KO,1]:0.F3H`$(#U@$`*!:[S(?6D#IDZ`!"`]8!`"@6N\S'UI`Z9.@`0@
M/6`0`H%KO-!]:0.F3H`$(#U@$`*!:[S4?6D#IDZ`!"`]8!`"@6N\V'UI`Z9.
M@`0@/6`0`H%KO-Q]:0.F3H`$(#U@$`*!:[S@?6D#IDZ`!"`]8!`"@6N\Y'UI
M`Z9.@`0@/6`0`H%KO.A]:0.F3H`$(#U@$`*!:[SL?6D#IDZ`!"`]8!`"@6N\
M\'UI`Z9.@`0@/6`0`H%KO/1]:0.F3H`$(#U@$`*!:[SX?6D#IDZ`!"`]8!`"
M@6N\_'UI`Z9.@`0@/6`0`H%KO0!]:0.F3H`$(#U@$`*!:[T$?6D#IDZ`!"`]
M8!`"@6N]"'UI`Z9.@`0@/6`0`H%KO0Q]:0.F3H`$(#U@$`*!:[T0?6D#IDZ`
M!"`]8!`"@6N]%'UI`Z9.@`0@/6`0`H%KO1A]:0.F3H`$(#U@$`*!:[T<?6D#
MIDZ`!"`]8!`"@6N]('UI`Z9.@`0@/6`0`H%KO21]:0.F3H`$(#U@$`*!:[TH
M?6D#IDZ`!"!(``%`2``!/$@``3A(``$T2``!,$@``2Q(``$H2``!)$@``2!(
M``$<2``!&$@``11(``$02``!#$@``0A(``$$2``!`$@``/Q(``#X2```]$@`
M`/!(``#L2```Z$@``.1(``#@2```W$@``-A(``#42```T$@``,Q(``#(2```
MQ$@``,!(``"\2```N$@``+1(``"P2```K$@``*A(``"D2```H$@``)Q(``"8
M2```E$@``)!(``",2```B$@``(1(``"`2```?$@``'A(``!T2```<$@``&Q(
M``!H2```9$@``&!(``!<2```6$@``%1(``!02```3$@``$A(``!$2```0$@`
M`#Q(```X2```-$@``#!(```L2```*$@``"1@````8````&````!@````8```
M`&````!@````8````#V`$`(]:_``@`R[Y#EKIV!\"0.F?`M:%(&,N^A]8%H4
M3H`$(&````!@````8````&````!@````8````&````"4(?_P?`@"II`!`!23
MP0`(0I\`!7_(`J8_W@`!.]YAK$O_OT&``0`4?`@#IH/!``@X(0`03H``(!`"
M/3P0`#Q@$`!28!``4E```@`!$`!>%!``7DP0`%Y<$`!>9!``7FP0`%YT$`!<
M,!``7DA?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````0`%XX
M$`!>0!``7#P0`%PP$`!;[!``6_`0`%XL$`!;?!``7C00`%PP$`!>&!``7B`0
M`%PP68``````````````0<____^```!005)?0TQ%04X````O<')O8R]S96QF
M+V5X90``)7,O)7,````O<')O8R\E:2\E<P!E>&4`)7,E<R5S``!015),-4Q)
M0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]414U0`````%!!4E]$14)51P```%!!4E]#
M04-(10```%!!4E]04D]'3D%-10````!005)?05)'0P````!005)?05)'5E\P
M``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%2
M7U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M4$%27T-,14%./0``,0```'!A<BT`````+64``"TM```N````)7,E<R5S)7,`
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``)7,Z('-T870@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E"@``<&%R;``````N<&%R`````"5S)7-C
M86-H92TE<R5S```E,#)X`````"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE
M=2TE=25S`````%-94U1%30``05)'5@`````8````<&5R;``````P````)7,Z
M(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H```!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC````26YT97)N86QS.CI005(Z
M.D)/3U0`````+P```%5315(`````55-%4DY!344`````5$5-4$1)4@!435``
M0SI<5$5-4``O=&UP`````#H```!,1%],24)205)97U!!5$@`3$E"4$%42`!,
M24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@````C(2]U<W(O8FEN
M+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO
M="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S
M=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R
M97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q
M>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N
M)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W
M:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T
M+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@
M>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H
M92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A
M;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK
M:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE
M<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@
M("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO
M;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@
M9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O
M8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI
M;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@
M("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@
M($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@
M("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+
M(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN
M+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G
M)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@
M*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@
M("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@
M("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@
M<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N
M86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@
M(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!
M4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@
M/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'
M0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*
M("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]]
M(&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@
M4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M
M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@
M8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S
M*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@
M(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@
M>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@
M(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX
M+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D
M8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@
M("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP
M86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@
M("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@
M(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY
M("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M
M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@
M(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`]
M(%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I
M('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D
M;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@
M(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@
M(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT
M(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@
M("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P
M<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T
M>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D
M8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@
M("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@
M("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]
M?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M
M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI
M<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E]
M(&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@
M("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L
M92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U
M9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@
M<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE
M;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@
M("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT
M("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L
M("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@
M("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D
M=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U
M;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE
M8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I
M<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H
M96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL
M93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@
M:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I
M;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@
M("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL
M97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI
M<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@
M("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]
M"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]
M?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C
M;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P
M("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@
M("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@
M("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I
M<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!0
M4D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@
M=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@
M=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO
M<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!
M4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*
M("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I
M('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I
M('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@
M("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@
M=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@
M/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@
M("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@
M("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@
M("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?
M:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@
M("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T
M(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@
M*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I
M<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@
M("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`[
M"@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F
M:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2([
M"B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I
M92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N
M=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@
M;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H
M9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O
M<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@
M("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@
M97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@
M.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O
M=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W
M+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@
M/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@
M("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?
M1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@
M:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N
M("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@
M?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@
M=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S
M('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ
M2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE
M<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE
M;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@
M("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@
M("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@
M0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I
M>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N
M=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET
M+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO
M(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D
M>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG
M('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E
M9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N
M9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@
M("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M
M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE
M<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@
M("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@
M:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@
M("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@
M("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@
M("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@
M("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@
M("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I
M*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@
M("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@
M("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@
M("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@
M1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER
M;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E
M=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@
M("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M
M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@
M("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@
M("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G
M:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@
M("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A
M;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X
M*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@
M)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@
M(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M
M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@
M(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z
M.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E
M($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M
M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@
M("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@
M("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@
M("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@
M("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@
M("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@
M("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@
M('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@
M("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)
M9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@
M*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R
M97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@
M(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q
M=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@
M0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R
M<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E
M($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL
M93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@
M6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z
M.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O
M;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R
M97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER
M92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#
M('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D
M:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP
M(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@
M("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@
M("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I
M"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE
M.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@
M979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W
M=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G
M.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U
M.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L
M("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8[
M"B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@
M("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@
M<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@
M("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I
M;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.
M?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!]
M(#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@
M("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS
M=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@
M;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T
M96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@
M("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@
M("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92![
M"B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I
M;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@
M;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@
M)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U
M<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@
M("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@
M)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@
M(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?
M9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@
M=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI
M;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*
M<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92![
M"B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@
M("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG
M4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%
M35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*
M("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*
M("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L
M96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q
M(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U
M8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H
M*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L
M<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?
M:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@
M("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X
M<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]
M"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K
M86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH```!P87(N<&P```$;`SL`
M```0`````?__7M0````H````$``````!>E(`!'Q!`1L,`0`````0````&/__
M7J0````D``````````#_____`````/____\``````````!`!O300`;J\$`&Z
MO`````$````!`````0```K(````!```"O0````$```+'`````0```Q8````!
M```$6@````P0`!C\````#1``6B`````$$``!B&___O40``3H````!1``#90`
M```&$``&1`````H```7\````"P```!`````5``````````,0`;OL`````@``
M`\`````4````!P```!<0`!4\<````!`!N^`````'$``5#`````@```/P````
M"0````QO___^$``4?&____\````";___\!``$Y``````````````````````
M````````````````````````````````````````````````$`&ZW```````
M````$`!8H!``6*00`%BH$`!8K!``6+`0`%BT$`!8N!``6+P0`%C`$`!8Q!``
M6,@0`%C,$`!8T!``6-00`%C8$`!8W!``6.`0`%CD$`!8Z!``6.P0`%CP$`!8
M]!``6/@0`%C\$`!9`!``6000`%D($`!9#!``61`0`%D4$`!9&!``61P0`%D@
M$`!9)!``62@0`%DL$`!9,!``6300`%DX$`!9/!``64`0`%E$$`!92!``64P0
M`%E0$`!95!``65@0`%E<$`!98!``6600`%EH$`!9;!``67`0`%ET$`!9>!``
M67P0`%F`$`!9A!``68@0`%F,$`!9D!``6900`%F8$`!9G!``6:`0`%FD$`!9
MJ!``6:P0`%FP$`!9M!``6;@0`%F\$`!9P!``6<00`%G($`!9S!``6=`0`%G4
M$`!9V!``6=P```````````````#_____$`"Z=```6^E'0T,Z("A$96)I86X@
M-"XT+C4M."D@-"XT+C4`1T-#.B`H1&5B:6%N(#0N-"XU+3$P*2`T+C0N-0!!
M````$V=N=0`!````"P0!"`$,`@`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!
M0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0R`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+G-D871A`"YB<W,`+F-O;6UE;G0`+F=N=2YA='1R
M:6)U=&5S````````````````````````````````````````````````````
M````````"P````$````"$``!-````30````-```````````````!````````
M`!,````'`````A```40```%$````(```````````````!``````````A````
M!P````(0``%D```!9````"0```````````````0`````````.`````4````"
M$``!B````8@```-@````!@`````````$````!````#1O___V`````A``!.@`
M``3H```!7`````8`````````!`````0````^````"P````(0``9$```&1```
M!U`````'`````0````0````0````1@````,````"$``-E```#90```7\````
M```````````!`````````$YO____`````A``$Y```!.0````Z@````8`````
M`````@````(```!;;____@````(0`!1\```4?````)`````'`````@````0`
M````````:@````0````"$``5#```%0P````P````!@`````````$````#```
M`'0````$`````A``%3P``!4\```#P`````8````8````!`````P```!^````
M`0````80`!C\```8_````$P```````````````0`````````A`````$````&
M$``94```&5```$#0```````````````0`````````(H````!````!A``6B``
M`%H@````.```````````````!`````````"0`````0````(0`%I8``!:6```
M8"0```````````````@`````````F`````$````"$`"Z?```NGP````4````
M```````````$`````````*8````!`````A``NI```+J0````+```````````
M````!`````````"P`````0````,0`;J\``"ZO`````@```````````````0`
M````````MP````$````#$`&ZQ```NL0````(```````````````$````````
M`+X````!`````Q`!NLP``+K,````!```````````````!`````````##````
M`0````,0`;K0``"ZT`````P```````````````$`````````R0````8````#
M$`&ZW```NMP```$`````!P`````````$````"````-(````!`````Q`!N]P`
M`+O<````$```````````````!`````0```!Y`````0````,0`;OL``"[[```
M`4````````````````0`````````UP````$````#$`&]+```O2P````0````
M```````````$`````````-T````!`````Q`!O3P``+T\````"```````````
M````!`````````#D````"`````,0`;U0``"]1```$$```````````````!``
M````````Z0````$````P````````O40````Y```````````````!`````0``
M`/)O___U`````````````+U]````%````````````````0`````````!````
A`P````````````"]D0```0(```````````````$`````
